# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 2.0.4

([Full Changelog](https://github.com/esdc-esac-esa-int/pyesasky/compare/a8c3190ae34e4338ab07028e5674fe02615344eb...5ef0c5a486dfd33eae7f0d30a51565bd08a571e7))

### Enhancements made

- Dynamically assign widget version [#60](https://github.com/esdc-esac-esa-int/pyesasky/pull/60) ([@esdc-esac-esa-int](https://github.com/esdc-esac-esa-int))
- Change version warning [#58](https://github.com/esdc-esac-esa-int/pyesasky/pull/58) ([@emellega](https://github.com/emellega))

### Bugs fixed

- Update check-release.yml [#59](https://github.com/esdc-esac-esa-int/pyesasky/pull/59) ([@esdc-esac-esa-int](https://github.com/esdc-esac-esa-int))

### Maintenance and upkeep improvements

- Bump vega from 5.30.0 to 5.33.0 in /ui-tests [#57](https://github.com/esdc-esac-esa-int/pyesasky/pull/57) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/esdc-esac-esa-int/pyesasky/graphs/contributors?from=2025-02-08&to=2025-05-02&type=c))

[@dependabot](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Adependabot+updated%3A2025-02-08..2025-05-02&type=Issues) | [@emellega](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aemellega+updated%3A2025-02-08..2025-05-02&type=Issues) | [@esdc-esac-esa-int](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aesdc-esac-esa-int+updated%3A2025-02-08..2025-05-02&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Agithub-actions+updated%3A2025-02-08..2025-05-02&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 2.0.3

([Full Changelog](https://github.com/esdc-esac-esa-int/pyesasky/compare/a8c3190ae34e4338ab07028e5674fe02615344eb...5ef0c5a486dfd33eae7f0d30a51565bd08a571e7))

### Enhancements made

- Dynamically assign widget version [#60](https://github.com/esdc-esac-esa-int/pyesasky/pull/60) ([@esdc-esac-esa-int](https://github.com/esdc-esac-esa-int))
- Change version warning [#58](https://github.com/esdc-esac-esa-int/pyesasky/pull/58) ([@emellega](https://github.com/emellega))

### Bugs fixed

- Update check-release.yml [#59](https://github.com/esdc-esac-esa-int/pyesasky/pull/59) ([@esdc-esac-esa-int](https://github.com/esdc-esac-esa-int))

### Maintenance and upkeep improvements

- Bump vega from 5.30.0 to 5.33.0 in /ui-tests [#57](https://github.com/esdc-esac-esa-int/pyesasky/pull/57) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/esdc-esac-esa-int/pyesasky/graphs/contributors?from=2025-02-07&to=2025-05-02&type=c))

[@dependabot](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Adependabot+updated%3A2025-02-07..2025-05-02&type=Issues) | [@emellega](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aemellega+updated%3A2025-02-07..2025-05-02&type=Issues) | [@esdc-esac-esa-int](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aesdc-esac-esa-int+updated%3A2025-02-07..2025-05-02&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Agithub-actions+updated%3A2025-02-07..2025-05-02&type=Issues)

## 2.0.2

No merged PRs

## 2.0.1

([Full Changelog](https://github.com/esdc-esac-esa-int/pyesasky/compare/1.9.5...5ef0c5a486dfd33eae7f0d30a51565bd08a571e7))

### Enhancements made

- Dynamically assign widget version [#60](https://github.com/esdc-esac-esa-int/pyesasky/pull/60) ([@esdc-esac-esa-int](https://github.com/esdc-esac-esa-int))
- Change version warning [#58](https://github.com/esdc-esac-esa-int/pyesasky/pull/58) ([@emellega](https://github.com/emellega))

### Bugs fixed

- Update check-release.yml [#59](https://github.com/esdc-esac-esa-int/pyesasky/pull/59) ([@esdc-esac-esa-int](https://github.com/esdc-esac-esa-int))

### Maintenance and upkeep improvements

- Bump vega from 5.30.0 to 5.33.0 in /ui-tests [#57](https://github.com/esdc-esac-esa-int/pyesasky/pull/57) ([@dependabot](https://github.com/dependabot))

### Other merged PRs

- pyESASky rework [#56](https://github.com/esdc-esac-esa-int/pyesasky/pull/56) ([@pmatsson](https://github.com/pmatsson))
- Updated version number to 1.9.5 [#52](https://github.com/esdc-esac-esa-int/pyesasky/pull/52) ([@imbasimba](https://github.com/imbasimba))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/esdc-esac-esa-int/pyesasky/graphs/contributors?from=2023-03-31&to=2025-05-02&type=c))

[@dependabot](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Adependabot+updated%3A2023-03-31..2025-05-02&type=Issues) | [@emellega](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aemellega+updated%3A2023-03-31..2025-05-02&type=Issues) | [@esdc-esac-esa-int](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aesdc-esac-esa-int+updated%3A2023-03-31..2025-05-02&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Agithub-actions+updated%3A2023-03-31..2025-05-02&type=Issues) | [@imbasimba](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Aimbasimba+updated%3A2023-03-31..2025-05-02&type=Issues) | [@pmatsson](https://github.com/search?q=repo%3Aesdc-esac-esa-int%2Fpyesasky+involves%3Apmatsson+updated%3A2023-03-31..2025-05-02&type=Issues)
